hilltopDepthProfile: Hilltop Depth Profile Measurement Request As A Data Frame.

View source: R/hillr_measurements.R

hilltopDepthProfileR Documentation

Hilltop Depth Profile Measurement Request As A Data Frame.

Description

hilltopDepthProfile returns a depth profile at times.

Usage

hilltopDepthProfile(url)

Arguments

url

A url that returns an XML document of a Hilltop Depth Profile.

Details

Function to process the XML from a Hilltop url request for Depth Profile data into a dataframe that contains the measurement information. It returns a dataframe of the data for depth and each profile timestamp, including measurement name and the Site Name.

Value

A dataframe of a depth profile from a Hilltop datasource.


jeffcnz/hillr documentation built on Nov. 21, 2024, 11:58 p.m.