hilltopEnsembleStatByTimePeriod: Hilltop Ensemble Statistics By Time Period.

View source: R/hillr_ensemble_stats.R

hilltopEnsembleStatByTimePeriodR Documentation

Hilltop Ensemble Statistics By Time Period.

Description

hilltopEnsembleStatsByTimePeriod return stats for each time period.

Usage

hilltopEnsembleStatByTimePeriod(xmldata)

Arguments

xmldata

An XML document, returned from a url request using anyXmlParse.

Details

Helper function that takes parsed xml from an EnsembleStats Request. Returns the statistics for each time period (depending whether hourly, monthly or annual stats).

Value

A dataframe of the of the summary statistics for each time period.


jeffcnz/hillr documentation built on Nov. 21, 2024, 11:58 p.m.