is.hilltopXml: Checks Whether XML Is Hilltop XML.

View source: R/hillr_helpers.R

is.hilltopXmlR Documentation

Checks Whether XML Is Hilltop XML.

Description

is.hilltopXml Checks if an xml document is hilltop xml, returns True or False accordingly.

Usage

is.hilltopXml(xmldata)

Arguments

xmldata

An XML document, returned from a url request using anyXmlParse.

Value

logical TRUE / FALSE


jeffcnz/hillr documentation built on Nov. 21, 2024, 11:58 p.m.