View source: R/hillr_measurements.R
| hilltopDepthProfile | R Documentation |
hilltopDepthProfile returns a depth profile at times.
hilltopDepthProfile(url)
url |
A url that returns an XML document of a Hilltop Depth Profile. |
Function to process the XML from a Hilltop url request for Depth Profile data into a dataframe that contains the measurement information. It returns a dataframe of the data for depth and each profile timestamp, including measurement name and the Site Name.
A dataframe of a depth profile from a Hilltop datasource.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.