View source: R/hillr_ensemble_stats.R
| hilltopEnsembleStatByTimePeriod | R Documentation |
hilltopEnsembleStatsByTimePeriod return stats for each time period.
hilltopEnsembleStatByTimePeriod(xmldata)
xmldata |
An XML document, returned from a url request using anyXmlParse. |
Helper function that takes parsed xml from an EnsembleStats Request. Returns the statistics for each time period (depending whether hourly, monthly or annual stats).
A dataframe of the of the summary statistics for each time period.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.