View source: R/hillr_helpers.R
| is.hilltopXml | R Documentation |
is.hilltopXml Checks if an xml document is hilltop xml, returns True or False accordingly.
is.hilltopXml(xmldata)
xmldata |
An XML document, returned from a url request using anyXmlParse. |
logical TRUE / FALSE
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.